<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Calendar_tipyan;
use App\Models\Presence;
use Carbon\Carbon;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class PresenceController extends BaseController
{
    // Get All Presences

    public function getData3(Request $request)
    {
        try {
            setlocale(LC_ALL, 'IND');
            Carbon::setLocale('id');
            $date = Calendar_tipyan::orderBy('date', 'desc');
            $date = $date->get();

            // $date->
            return $this->sendResponse($date, '   تم التحديث بنجاح');

        } catch (Exception $e) {
            $this->sendError($e->getMessage(), ['trace' => $e->getTrace()], 500);
        }
    }
    public function getData(Request $request)
    {
        try {
            setlocale(LC_ALL, 'IND');
            Carbon::setLocale('id');
            $presences = Presence::where(['user_id' => Auth::user()->id])->orderBy('id', 'desc');
            if ($request->limit) {
                $presences = $presences->take($request->limit);
            }
            $presences = $presences->get();
            $presences = $presences->map(function ($presence) {
                $presence->date = Carbon::parse($presence->date)->isoFormat('D MMMM Y');
                return $presence;
            });
            return $this->sendResponse($presences, 'استرجاع بيانات الحضور بنجاح');
        } catch (Exception $e) {
            $this->sendError($e->getMessage(), ['trace' => $e->getTrace()], 500);
        }
    }
    // Count Presences
    public function countPresences(Request $request)
    {
        try {
            $maxDays = date('t');
            $attendance = Presence::where(['user_id' => Auth::user()->id, 'type' => 'checkin'])->whereMonth('date', date('m'))->whereYear('date', date('Y'))->get();
            $data = [
                'attendance' => $attendance->count(),
                'absence' => $maxDays - $attendance->count(),
            ];
            return $this->sendResponse($data, 'استرجاع عدد الغيابات بنجاح.');
        } catch (Exception $e) {
            $this->sendError($e->getMessage(), ['trace' => $e->getTrace()], 500);
        }
    }
    // Get Presence By ID
    public function getPresenceById(Request $request, Presence $presence)
    {
        try {
            if (!$presence) {
                return $this->sendError('لم يتم العثور على بيانات', [], 404);
            }
            $data = [
                'date' => Carbon::parse($presence->date)->isoFormat('D MMMM Y'),
                'shift' => 'Pukul ' . $presence->shift->start_entry . ' s/d ' . $presence->shift->start_time_exit,
                'type' => $presence->type == 'checkin' ? 'دخول' : 'خروج',
                'time_in' => Carbon::parse($presence->time_in)->isoFormat('HH:mm'),
                'location' => $presence->latitude . ', ' . $presence->longitude,
                // 'description' => $presence->description,
            ];
            return $this->sendResponse($data, 'استرجاع بيانات الحضور بنجاح.');
        } catch (Exception $e) {
            $this->sendError($e->getMessage(), ['trace' => $e->getTrace()], 500);
        }
    }

    // Create Presence
    // public function createPresence(Request $request)
    // {
    //     try {
    //         $strParse = explode('-', $request->qr_data);
    //         $type = $strParse[0] == 'YPO' ? 'checkin' : 'checkout';
    //         $date = Carbon::createFromFormat('Y-m-d', $strParse[2] . '-' . $strParse[3] . '-' . $strParse[4]);
    //         // $strParse = explode('-', $request->qr_data);
    //         // $type = $strParse[0] == 'datang' ? 'checkin' : 'checkout';
    //         // $type = $request->qr_data == 'YPO-A-'.Carbon::now()->format('Y-m-d') ? 'checkin' : 'checkout';
    //         // $type = 'checkin';
    //         // $date = Carbon::createFromFormat('Y-m-d', 2023 . '-' . 1 . '-' . 1);
    //         $request->merge(['type' => $type, 'date' => $date->format('Y-m-d')]);
    //         $shift = Auth::user()->shift()->first();
    //         if ($type == 'checkin') {
    //             $checkin = null;
    //             Presence::where(['user_id' => Auth::user()->id, 'type' => 'checkin', 'date' => $date->format('Y-m-d')])->first();
    //             if (!$checkin) {
    //                 if (Carbon::now()->format('H:i:s') < $shift->start_time_entry) {
    //                     $description = 'تسجيل الدخول في الوقت المحدد';
    //                 } else {
    //                     $description = 'تسجيل دخول متأخر';
    //                 }
    //                 $request->merge(['description' => $description]);
    //                 $presence = $this->_store($request);
    //                 $data = [
    //                     'date' => Carbon::parse($presence->date)->isoFormat('D MMMM Y'),
    //                     'type' => $presence->type,
    //                     'time_in' => $presence->time_in,
    //                     'latitude' => $presence->latitude,
    //                     'longitude' => $presence->longitude,
    //                     'description' => $presence->description,
    //                 ];
    //                 return $this->sendResponse($data, 'تم تحضيرك بنجاح');
    //             } else {
    //                 return $this->sendError('لقد تأخرت اليوم ', [], 400);
    //             }
    //         } else {
    //             $checkout = Presence::where(['user_id' => Auth::user()->id, 'type' => 'checkout', 'date' => $date->format('Y-m-d')])->first();
    //               if (!$checkout) {
    //                 if (Carbon::now()->format('H:i:s') < $shift->start_exit) {
    //                     Presence::where(['user_id' => Auth::user()->id, 'date' => Carbon::now()->format('Y-m-d')])->delete();
    //                     $this->sendResponse(null, 'لا يلهيك عملك عن ماهو اعظم ');
    //                 } else {
    //                     $description = 'تم الاستماع';
    //                     $request->merge(['description' => $description]);
    //                     $presence = $this->_store($request);
    //                     $data = [
    //                         'date' => Carbon::parse($presence->date)->isoFormat('D MMMM Y'),
    //                         'type' => $presence->type,
    //                         'time_in' => $presence->time_in,
    //                         'latitude' => $presence->latitude,
    //                         'longitude' => $presence->longitude,
    //                         'description' => $presence->description,
    //                     ];
    //                     return $this->sendResponse($data, 'تم اثبات حضورك');
    //                 }
    //             } else {
    //                 return $this->sendError('اخطأت في قراة الكود او ان رمز الكود غير صحيح  ', [], 400);
    //             }
    //         }
    //     } catch (Exception $e) {
    //         $this->sendError($e->getMessage(), ['trace' => $e->getTrace()], 500);
    //     }
    // }
    public function createPresence(Request $request)
    {
        try {


            $strParse = explode('-', $request->qr_data);
            $type = $strParse[0] == 'YPO' ? 'checkin' : 'checkout';

             if(count($strParse) == 6 && $type == 'checkin'){
                // $place = $strParse[1];

                $request->merge(['presence_type_id' => $strParse[1]]);
                // $request->merge(['type_lecture' => $strParse[2]]);
                $date = Carbon::createFromFormat('Y-m-d', $strParse[3] . '-' . $strParse[4] . '-' . $strParse[5]);
                $request->merge(['type' => $type, 'date' => $date->format('Y-m-d')]);
                // $shift = Auth::user()->shift()->first();

                   if ($type == 'checkin') {

                       if(Carbon::now()->format('Y-m-d') != $date->format('Y-m-d') && $strParse[2] == 'A'){

                               return $this->sendError('لقد انتهت مدة كود التحضير ', [], 400);

                       }
                   $checkin = Presence::where(['user_id' => Auth::user()->id, 'type' => 'checkin', 'date' => $date->format('Y-m-d'),'presence_type_id' => $strParse[1]])->first();
                  $checkin1 = Presence::where([ 'mobile_id' => $request->mobile_id , 'date' => $request->date ])->where('user_id','!=' ,Auth::user()->id)->first();
                    if($checkin1){
                // $checkin2 = Presence::whereNot('user_id', Auth::user()->id)->first();

                return $this->sendError('لا يسمح بدخول شخص اخر من نفس الهاتف ', [], 400);
              }
               else   if (!$checkin) {
                    // if (Carbon::now()->format('H:i:s') < $shift->start_time_entry) {
                    //     $description = 'مبكر';
                    // } else {
                    //     $description = 'متأخر';
                    // }
                    // $request->merge(['place' => $place]);

                    // $request->merge(['description' => $description]);
                    $presence = $this->_store($request);
                    $data = [
                        'date' => Carbon::parse($presence->date)->isoFormat('D MMMM Y'),
                        'type' => $presence->type,
                        'time_in' => $presence->time_in,
                        'latitude' => $presence->latitude,
                        'longitude' => $presence->longitude,
                        // 'place' => $presence->place,
                        'login' => 'mobile',
                        // 'type_lecture' => $presence->type_lecture,
                        'mobile_id' => $presence->mobile_id,
                        // 'description' => $presence->description,
                    ];
                    return $this->sendResponse($data, 'تم تحضيرك بنجاح');
                }
                else {
                    return $this->sendError('لقد تم التحضير من قبل', [], 400);
                }
            } else {
                $checkout = Presence::where(['user_id' => Auth::user()->id, 'type' => 'checkout', 'date' => $date->format('Y-m-d')])->first();
                if (!$checkout) {
                    // if (Carbon::now()->format('H:i:s') < $shift->start_exit) {
                        Presence::where(['user_id' => Auth::user()->id, 'date' => Carbon::now()->format('Y-m-d')])->delete();
                        $this->sendResponse(null, 'انتظر لتستفيد.');
                    // } else {
                        // $description = 'تم الاستماع';
                        // $request->merge(['description' => $description]);
                        // $request->merge(['place' => $place]);

                        $presence = $this->_store($request);
                        $data = [
                            'date' => Carbon::parse($presence->date)->isoFormat('D MMMM Y'),
                            'type' => $presence->type,
                            'time_in' => $presence->time_in,
                            'latitude' => $presence->latitude,
                            'longitude' => $presence->longitude,
                            // 'place' => $presence->place,
                            'login' => 'mobile',
                            // 'type_lecture' => $presence->type_lecture,
                            'mobile_id' => $presence->mobile_id,
                            // 'description' => $presence->description,
                        ];
                        return $this->sendResponse($data, 'تم اثبات حضورك');
                    // }
                } else {
                    return $this->sendError('خطأ في قراة الكود او ان رمز الكود غير صحيح .', [], 400);
                }
              }

            }else{
                return $this->sendError(' * خطأ في قراة الكود او ان رمز الكود غير صحيح .', [], 400);
            }
        } catch (Exception $e) {
            $this->sendError($e->getMessage(), ['trace' => $e->getTrace()], 500);
        }
    }

        private function _store(Request $request)
    {
        $presence = Presence::create([
            'user_id' => Auth::user()->id,
            // 'shift_id' => Auth::user()->shift_id,
            'presence_type_id' => $request->presence_type_id,
            'date' => $request->date,
            'type' => $request->type,
            'login' => 'mobile',
            // 'place' => $request->place,
            // 'type_lecture' => $request->type_lecture,
            'mobile_id' => $request->mobile_id,
            'time_in' => Carbon::now()->format('H:i:s'),
            'latitude' => $request->latitude,
            'longitude' => $request->longitude,
            // 'description' => $request->description,
        ]);
        return $presence;
    }
}
