<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Contracts\Support\Renderable;
use App\Models\BoycottCategory;
use Illuminate\Http\Request;
use Inertia\Inertia;
use App\Traits\UploadTrait;
class BoycottCategoryController extends Controller
{


    /**
 * Display a listing of the resource.
 * @return Renderable
 */
use UploadTrait;
// use boycott_categorieservice;
public function __construct(){
    $this->middleware('permission:boycott_categories-create', ['only' => ['create','store']]);
    $this->middleware('permission:boycott_categories-update',   ['only' => ['edit','update']]);
    $this->middleware('permission:boycott_categories-read',   ['only' => ['show', 'index']]);
    $this->middleware('permission:boycott_categories-delete',   ['only' => ['destroy']]);
    $this->middleware('permission:boycott_categories-eye',   ['only' => ['eye']]);
}
public function eye($id)
{
    $active = BoycottCategory::find($id);
    if ($active->active == 1) {$active->active = 0;} else {$active->active = 1;}$active->save();
    // return $active->active;
    return response()->json(["success" => true, "eye" => $active], 200);
}
public function index(Request $request)
{
    $per_page = $request->itemsPerPage ?? 10;
    $orderBy = $request->sortBy ?? "id";
    $orderDir = $request->sortDesc ?? "desc";
   $boycott_categories = BoycottCategory::orderBy($orderBy, $orderDir)
        ->filter($request->only('search'))
        ->paginate($per_page)
        ->appends(['search' => $request->only('search')]);
    if ($request->wantsJson()) {
        return $boycott_categories;
    }
    return Inertia::render("Admin/BoycottCategory/Index", ["boycott_categories" => $boycott_categories]);
}

/**
 * Show the form for creating a new resource.
 * @return Renderable
 */
public function create()
{
    return Inertia::render("Admin/BoycottCategory/Create");
}

public function gitBoycottCategory($id)
{
    $gitsubcategories =  BoycottCategory::where('category_id',$id)->get();
    return response()->json(["success" => true, "gitsubcategories" => $gitsubcategories], 200);
}
/**
 * Store a newly created resource in storage.
 * @param Request $request
 * @return Renderable
 */
public function store(Request $request)
{

    $request->validate([
        'name' => 'required|string|unique:boycott_categories,name',
    ]);
    $boycott_categories = new BoycottCategory();
    $boycott_categories->user_id =auth()->user()->id;
    $boycott_categories->name = $request->name;
    $boycott_categories->name_en = $request->name_en;
    $boycott_categories->image =$this->storeImage($request['image'],'images/boycott_categories');

    $boycott_categories->save();
    return redirect()->route("boycott_categories.index")->with('success', 'تم اضافة  بنجاح');
}

/**
 * Show the specified resource.
 * @param int $id
 * @return Renderable
 */
public function show($id)
{

}

/**
 * Show the form for editing the specified resource.
 * @param int $id
 * @return Renderable
 */
public function edit($id)
{
    $boycott_categories =  BoycottCategory::find($id);

    return Inertia::render("Admin/BoycottCategory/Edit", ["boycott_categories" => $boycott_categories]);
}

/**
 * Update the specified resource in storage.
 * @param Request $request
 * @param int $id
 * @return Renderable
 */
public function update2(Request $request)
{
    $request->validate([
      'name'     => 'required|string|unique:boycott_categories,name,'.$request->id,
    ]);
    $boycott_categories =  BoycottCategory::find($request->id);
    $boycott_categories->user_id   = auth()->user()->id;
    $boycott_categories->name = $request->name;
    $boycott_categories->name_en = $request->name_en;

    if($request['image'] != null)
    $boycott_categories->image =$this->updateImage($request['image'],'images/boycott_categories',$boycott_categories->image);
    $boycott_categories->save();
    return redirect()->route("boycott_categories.index")->with('success', 'تم التعديل   بنجاح');
}

/**
 * Remove the specified resource from storage.
 * @param int $id
 * @return Renderable
 */
public function destroy($id)
{
// $boycott_categories= BoycottCategory::find($id);
// $this->deleteImage($boycott_categories->image);
// $boycott_categories->delete();

$boycott_categories = BoycottCategory::find($id);
$this->deleteImage($boycott_categories->image);
$boycott_categories->delete();
return true;
}
}
