<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Contracts\Support\Renderable;
use App\Models\BoycottProduct;

use App\Models\BoycottCategory;
use App\Models\BoycottCompany;
use Illuminate\Http\Request;

use Inertia\Inertia;
use App\Traits\UploadTrait;
class BoycottProductController extends Controller
{

    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    use UploadTrait;
    // use boycott_productservice;
    public function __construct()
    {
        $this->middleware('permission:boycott_products-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:boycott_products-update',   ['only' => ['edit', 'update']]);
        $this->middleware('permission:boycott_products-read',   ['only' => ['show', 'index']]);
        $this->middleware('permission:boycott_products-delete',   ['only' => ['destroy']]);
        $this->middleware('permission:boycott_products-eye',   ['only' => ['eye']]);
    }
    public function eye($id)
    {
        $active = BoycottProduct::find($id);
        if ($active->active == 1) {
            $active->active = 0;
        } else {
            $active->active = 1;
        }
        $active->save();
        // return $active->active;
        return response()->json(["success" => true, "eye" => $active], 200);
    }
    public function index(Request $request)
    {
        $per_page = $request->itemsPerPage ?? 10;
        $orderBy = $request->sortBy ?? "id";
        $orderDir = $request->sortDesc ?? "desc";
        $boycott_products = BoycottProduct::orderBy($orderBy, $orderDir)
            ->filter($request->only('search'))
            ->paginate($per_page)
            ->appends(['search' => $request->only('search')]);
        if ($request->wantsJson()) {
            return $boycott_products;
        }
        return Inertia::render("Admin/BoycottProduct/Index", ["boycott_products" => $boycott_products]);
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {
        $boycott_categories =  BoycottCategory::all();
        $boycott_companies =  BoycottCompany::all();
        return Inertia::render("Admin/BoycottProduct/Create", ["boycott_companies" => $boycott_companies, "boycott_categories" => $boycott_categories]);
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
    // boycott_companies_id
    // boycott_categories_id
    // name
    // details
    // reason_boycott
    // name_en
    // details_en
    // reason_boycott_en
    // qr_code
    // pr_code
    // image
        $request->validate([
            'name' => 'required|string|unique:boycott_products,name',
            'pr_code' => 'required|integer',
            'boycott_companies_id'          => 'required',
            'boycott_categories_id'         => 'required',
            // 'image'               => 'required',
        ]);
        $boycott_products = new BoycottProduct();
        $boycott_products->user_id = auth()->user()->id;
        $boycott_products->name = $request->name;
        $boycott_products->boycott_companies_id = $request->boycott_companies_id;
        $boycott_products->boycott_categories_id = $request->boycott_categories_id;
        $boycott_products->details = $request->details;
        $boycott_products->reason_boycott = $request->reason_boycott;
        $boycott_products->name_en = $request->name_en;
        $boycott_products->details_en = $request->details_en;
        $boycott_products->reason_boycott_en = $request->reason_boycott_en;
        $boycott_products->qr_code = $request->qr_code;
        $boycott_products->pr_code = $request->pr_code;
        $boycott_products->image = $this->storeImage($request['image'], 'images/boycott_products');
        $boycott_products->save();
        return redirect()->route("boycott_products.index")->with('success', 'تم اضافة  بنجاح');
    }
    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {

        $boycott_categories =  BoycottCategory::all();
        $boycott_companies =  BoycottCompany::all();
        $boycott_products =  BoycottProduct::find($id);
        return Inertia::render("Admin/BoycottProduct/Edit", ["boycott_products" => $boycott_products,"boycott_companies" => $boycott_companies, "boycott_categories" => $boycott_categories,]);
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Renderable
     */
    public function update2(Request $request)
    {

     // dd($request);
        $request->validate([
            'name'     => 'required|string|unique:boycott_products,name,' . $request->id,
            'pr_code' => 'required|integer',
            'boycott_companies_id'          => 'required',
            'boycott_categories_id'         => 'required',
        ]);
        $boycott_products =  BoycottProduct::find($request->id);
        $boycott_products->user_id   = auth()->user()->id;
        $boycott_products->name = $request->name;
        $boycott_products->boycott_companies_id = $request->boycott_companies_id;
        $boycott_products->boycott_categories_id = $request->boycott_categories_id;
        $boycott_products->details = $request->details;
        $boycott_products->reason_boycott = $request->reason_boycott;
        $boycott_products->name_en = $request->name_en;
        $boycott_products->details_en = $request->details_en;
        $boycott_products->reason_boycott_en = $request->reason_boycott_en;
        $boycott_products->qr_code = $request->qr_code;
        $boycott_products->pr_code = $request->pr_code;
        if ($request['image'] != null)
            $boycott_products->image = $this->updateImage($request['image'], 'images/boycott_products', $boycott_products->image);
        $boycott_products->save();
        return redirect()->route("boycott_products.index")->with('success', 'تم التعديل   بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function destroy($id)
    {
        $boycott_products = BoycottProduct::find($id);
        $this->deleteImage($boycott_products->image);
        $boycott_products->delete();
        return true;
    }
}
