<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Permission;
use App\Models\Role;
use App\Traits\OrginaizePermissionTrait;
use Illuminate\Http\Request;
use Inertia\Inertia;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use App\Http\Requests\RoleRequest;
use App\Models\User;

class RoleController extends Controller
{
    use OrginaizePermissionTrait;

    public function __construct(){
        $this->middleware('permission:roles-create', ['only' => ['create','store']]);
        $this->middleware('permission:roles-update',   ['only' => ['edit','update']]);
        $this->middleware('permission:roles-read',   ['only' => ['show', 'index']]);
        $this->middleware('permission:roles-delete',   ['only' => ['destroy']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $per_page = $request->itemsPerPage ?? 20;
        $orderBy = $request->sortBy ?? "id";
        $orderDir = $request->sortDesc ?? "desc";
        // // $orderBy = $request->sortBy ?? "id";
        // // $orderDir = $request->sortDesc==null ? "desc" :( $request->sortDesc == false ?"asc" : "desc");

        // // dd(array_column(Role::orderBy("display_name","asc")->get()->toArray(),"display_name"));
        // $roles = Role::orderBy($orderBy, $orderDir)
        //     ->filter($request->only('search'))
        //     ->paginate($per_page)
        //     ->appends(['search' => $request->only('search')]);
        // if ($request->wantsJson()) {

        //     return $roles;
        // }
        $roles=$this->filterRolesForCurrentUser()->toQuery();
        $roles=$roles

             ->orderBy($orderBy, $orderDir)

             ->filter($request->only('search'))
             ->paginate($per_page)
             ->appends(['search' => $request->only('search')])
             ;
             if ($request->wantsJson()) {

                return $roles;
            }

        return Inertia::render("Admin/Roles/Index",["roles"=>$roles]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // $names = $permissions = [];

        $permissions=$this->OrginaizePermission();

        return Inertia::render("Admin/Roles/Create",[

            "permissions"=>$permissions,
            // 'names'=>$names
            ]);
    }


    /**
     * Store a newly created resource in storage.
     *  \App\Http\Requests\ٌRoleRequest
     * @param  \App\Http\Requests\RoleRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {



        $role=new Role( );
        $role->name=$request->name;
        $role->display_name=$request->display_name;
        $role->description=$request->description;
        $role->save();
         $role->permissions()->sync($request->selected_permission);

         return redirect()->route("roles.index")->with("success","تم اضافة الدور بنجاح");
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        return redirect()->back();
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $role=Role::find($id);
        if(!$role){
            return redirect()->route("roles.index")->with("error","هذا الدور غير موجود");
        }
        if(!$this->filterRoleForCurrentUser($role)){


            return redirect()->route("roles.index")->with("error","ليس لديك صلاحيات لتعديل هذا الدور");
        }
         $user_roles=auth()->user()->roles->first();

        if($user_roles && $user_roles->id ==$role->id ){

            return redirect()->route("roles.index")->with("error","ليس لديك صلاحيات لتعديل هذا الدور");
        }


        // dd(array_column( $role->permissions->toArray(),"id"));
        $role_permissions=array_column( $role->permissions->toArray(),"id");
        $permissions=$this->OrginaizePermission();

        return Inertia::render("Admin/Roles/Edit",[
            "role"=>$role,
            "permissions"=>$permissions,
            "role_permissions"=>$role_permissions
            // 'names'=>$names
            ]);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $role=Role::find($id);
        if(!$role){
            return redirect()->route("roles.index")->with("error","هذا الدور غير موجود");
        }

        $user_roles=auth()->user()->roles->first();

        if($user_roles && $user_roles->id ==$role->id ){

            return redirect()->route("roles.index")->with("error","ليس لديك صلاحيات لتعديل هذا الدور");
        }

        Validator::make($request->all(), [
            "name"=> ["required","string", Rule::unique('roles')->ignore($id)],
            "display_name" => ["required" ,"string"],
            "description" => ["nullable","string" ],
        ])->validate();

      $role->name=$request->name;
        $role->display_name=$request->display_name;
        $role->description=$request->description;
        $role->save();
         $role->permissions()->sync($request->selected_permission);

         return redirect()->route("roles.index")->with("success","تم تعديل الدور بنجاح");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $role=Role::find($id);
        if(!$role){
            return redirect()->route("roles.index")->with("error","هذا الدور غير موجود");
        }

        $user_roles=auth()->user()->roles->first();

        if($user_roles && $user_roles->id ==$role->id ){
            // abort(403,"ليس لديك صلاحيات لحذف هذا الدور");
              return redirect()->route("roles.index")->with("error","ليس لديك صلاحيات لحذف هذا الدور");

        }

        $role->delete();
        return redirect()->route("roles.index")->with("success","تم حذف الدور بنجاح");
    }
}
